@@ -3,8 +3,9 @@
 // This source code is licensed under the MIT license found in the
 // LICENSE file in the root directory of this source tree.
 
+use alloc::vec::Vec;
+use core::cmp::min;
 use rand::{CryptoRng, Error, RngCore};
-use std::cmp::min;
 
 /// A simple implementation of `RngCore` for testing purposes.
 ///
